# Project Information

Claude Knowledge Catalystプロジェクトに関する情報とリソースです。

## Contents

```{toctree}
:maxdepth: 2
:caption: Project Information
:hidden:

```

## プロジェクト概要

### ミッション
Claude Codeとの開発プロセスで生まれる知見を自動的に構造化し、長期的な知識資産として蓄積・活用するための包括的なプラットフォームを提供する。

### ビジョン
知識の触媒作用により、個人とチームの学習効率を飛躍的に向上させ、AI時代の知識ワーカーをエンパワーする。

### 価値観
- **自動化**: 手作業を最小限に抑え、自動的な知識管理を実現
- **構造化**: 情報を体系的に整理し、アクセスしやすい形で保存
- **統合**: 既存のツールやワークフローとシームレスに統合
- **進化**: 継続的な改善と新機能の追加
- **オープン**: オープンソースとして、コミュニティと共に成長

## 主要機能

- 適応型システム基盤による知識成熟度管理
- インテリジェント分類システム
- Obsidian深層統合
- プロジェクト横断知識関連付け

## 技術仕様

- **Pythonランタイム**: 3.11以上（uvが自動管理）
- **パッケージマネージャー**: uv
- **主要依存関係**: Pydantic, Typer, Rich, Watchdog
- **ドキュメント**: Sphinx + MyST Parser

## プロジェクト統計

### 使用技術

#### Core Technologies
```python
technologies = {
    "language": "Python 3.11+",
    "framework": "Typer + Rich",
    "data_validation": "Pydantic",
    "file_watching": "Watchdog",
    "templating": "Jinja2",
    "git_integration": "GitPython",
    "testing": "pytest + coverage",
    "documentation": "Sphinx + MyST Parser"
}
```

#### Development Tools
- **Linting**: Ruff
- **Type Checking**: MyPy
- **Package Management**: uv
- **CI/CD**: GitHub Actions
- **Code Quality**: pre-commit hooks

## ライセンスと著作権

### ライセンス
MIT License - 商用利用、改変、配布を自由に行えます。

### 著作権
```
Copyright (c) 2024-2025 driller

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction...
```

詳細は **LICENSE** ファイルを参照してください（準備中）。

## 貢献とサポート

### 貢献方法
1. **コード貢献**: Contributing Guide（準備中）
2. **バグ報告**: [GitHub Issues](https://github.com/drillan/claude-knowledge-catalyst/issues)
3. **機能要望**: [GitHub Discussions](https://github.com/drillan/claude-knowledge-catalyst/discussions)
4. **ドキュメント改善**: [Documentation Issues](https://github.com/drillan/claude-knowledge-catalyst/issues?q=is%3Aissue+is%3Aopen+label%3Adocumentation)

### サポート
- **ドキュメント**: この包括的なドキュメント
- **コミュニティ**: GitHub Discussions, Discord
- **FAQ**: よくある質問（準備中）
- **トラブルシューティング**: 問題解決ガイド（準備中）

## 関連プロジェクト

### 統合ツール
- **Obsidian**: 知識管理ボルト
- **Claude Code**: 自動化開発支援
- **VS Code**: 開発環境統合

### 類似プロジェクト
- **Logseq**: ブロックベース知識管理
- **Roam Research**: 双方向リンク知識管理
- **Notion**: 統合ワークスペース

## アクセシビリティ

### 言語サポート
- **プライマリ**: 日本語
- **セカンダリ**: 英語
- **UI**: 多言語対応準備中

### プラットフォーム
- **OS**: Windows, macOS, Linux
- **Python**: 3.11以上
- **アーキテクチャ**: x86_64, ARM64

## 連絡先

- **GitHub**: [drillan/claude-knowledge-catalyst](https://github.com/drillan/claude-knowledge-catalyst)
- **Documentation**: [https://claude-knowledge-catalyst.readthedocs.io/](https://claude-knowledge-catalyst.readthedocs.io/)
- **Issues**: [GitHub Issues](https://github.com/drillan/claude-knowledge-catalyst/issues)
- **Discussions**: [GitHub Discussions](https://github.com/drillan/claude-knowledge-catalyst/discussions)

---

*最終更新: 2025年6月*
